==> vtk6-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkChartParallelCoordinates.java <==
// java wrapper for vtkChartParallelCoordinates object
//

package vtk;
import vtk.*;

public class vtkChartParallelCoordinates extends vtkChart
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Update_2();
  public void Update()
    { Update_2(); }

  private native boolean Paint_3(vtkContext2D id0);
  public boolean Paint(vtkContext2D id0)
    { return Paint_3(id0); }

  private native void SetColumnVisibility_4(String id0,boolean id1);
  public void SetColumnVisibility(String id0,boolean id1)
    { SetColumnVisibility_4(id0,id1); }

  private native void SetColumnVisibilityAll_5(boolean id0);
  public void SetColumnVisibilityAll(boolean id0)
    { SetColumnVisibilityAll_5(id0); }

  private native boolean GetColumnVisibility_6(String id0);
  public boolean GetColumnVisibility(String id0)
    { return GetColumnVisibility_6(id0); }

  private native long GetVisibleColumns_7();
  public vtkStringArray GetVisibleColumns() {
    long temp = GetVisibleColumns_7();

    if (temp == 0) return null;
    return (vtkStringArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetPlot_8(int id0);
  public vtkPlot GetPlot(int id0) {
    long temp = GetPlot_8(id0);

    if (temp == 0) return null;
    return (vtkPlot)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native int GetNumberOfPlots_9();
  public int GetNumberOfPlots()
    { return GetNumberOfPlots_9(); }

  private native long GetAxis_10(int id0);
  public vtkAxis GetAxis(int id0) {
    long temp = GetAxis_10(id0);

    if (temp == 0) return null;
    return (vtkAxis)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native int GetNumberOfAxes_11();
  public int GetNumberOfAxes()
    { return GetNumberOfAxes_11(); }

  private native void RecalculateBounds_12();
  public void RecalculateBounds()
    { RecalculateBounds_12(); }

  private native void SetPlot_13(vtkPlotParallelCoordinates id0);
  public void SetPlot(vtkPlotParallelCoordinates id0)
    { SetPlot_13(id0); }

  public vtkChartParallelCoordinates() { super(); }

  public vtkChartParallelCoordinates(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-2-aarch64.pkg.tar.xz: vtk/vtkChartParallelCoordinates.java <==
// java wrapper for vtkChartParallelCoordinates object
//

package vtk;
import vtk.*;

public class vtkChartParallelCoordinates extends vtkChart
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Update_2();
  public void Update()
    { Update_2(); }

  private native boolean Paint_3(vtkContext2D id0);
  public boolean Paint(vtkContext2D id0)
    { return Paint_3(id0); }

  private native void SetColumnVisibility_4(String id0,boolean id1);
  public void SetColumnVisibility(String id0,boolean id1)
    { SetColumnVisibility_4(id0,id1); }

  private native void SetColumnVisibilityAll_5(boolean id0);
  public void SetColumnVisibilityAll(boolean id0)
    { SetColumnVisibilityAll_5(id0); }

  private native boolean GetColumnVisibility_6(String id0);
  public boolean GetColumnVisibility(String id0)
    { return GetColumnVisibility_6(id0); }

  private native long GetVisibleColumns_7();
  public vtkStringArray GetVisibleColumns() {
    long temp = GetVisibleColumns_7();

    if (temp == 0) return null;
    return (vtkStringArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetPlot_8(int id0);
  public vtkPlot GetPlot(int id0) {
    long temp = GetPlot_8(id0);

    if (temp == 0) return null;
    return (vtkPlot)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetNumberOfPlots_9();
  public int GetNumberOfPlots()
    { return GetNumberOfPlots_9(); }

  private native long GetAxis_10(int id0);
  public vtkAxis GetAxis(int id0) {
    long temp = GetAxis_10(id0);

    if (temp == 0) return null;
    return (vtkAxis)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetNumberOfAxes_11();
  public int GetNumberOfAxes()
    { return GetNumberOfAxes_11(); }

  private native void RecalculateBounds_12();
  public void RecalculateBounds()
    { RecalculateBounds_12(); }

  private native void SetPlot_13(vtkPlotParallelCoordinates id0);
  public void SetPlot(vtkPlotParallelCoordinates id0)
    { SetPlot_13(id0); }

  public vtkChartParallelCoordinates() { super(); }

  public vtkChartParallelCoordinates(long id) { super(id); }
  public native long   VTKInit();

}
